==> lsb-build-base2_2.1.1.orig.tar.gz: lsb-build-base2-2.1.1.orig/build_env/stub_libs/S390X/libm.c <==
void __finite() {} ;
void __finitef() {} ;
void __finitel() {} ;
void __fpclassify() {} ;
void __fpclassifyf() {} ;
void acos() {} ;
void acosf() {} ;
void acosh() {} ;
void acoshf() {} ;
void acoshl() {} ;
void acosl() {} ;
void asin() {} ;
void asinf() {} ;
void asinh() {} ;
void asinhf() {} ;
void asinhl() {} ;
void asinl() {} ;
void atan() {} ;
void atan2() {} ;
void atan2f() {} ;
void atan2l() {} ;
void atanf() {} ;
void atanh() {} ;
void atanhf() {} ;
void atanhl() {} ;
void atanl() {} ;
void cabs() {} ;
void cabsf() {} ;
void cabsl() {} ;
void cacos() {} ;
void cacosf() {} ;
void cacosh() {} ;
void cacoshf() {} ;
void cacoshl() {} ;
void cacosl() {} ;
void carg() {} ;
void cargf() {} ;
void cargl() {} ;
void casin() {} ;
void casinf() {} ;
void casinh() {} ;
void casinhf() {} ;
void casinhl() {} ;
void casinl() {} ;
void catan() {} ;
void catanf() {} ;
void catanh() {} ;
void catanhf() {} ;
void catanhl() {} ;
void catanl() {} ;
void cbrt() {} ;
void cbrtf() {} ;
void cbrtl() {} ;
void ccos() {} ;
void ccosf() {} ;
void ccosh() {} ;
void ccoshf() {} ;
void ccoshl() {} ;
void ccosl() {} ;
void ceil() {} ;
void ceilf() {} ;
void ceill() {} ;
void cexp() {} ;
void cexpf() {} ;
void cexpl() {} ;
void cimag() {} ;
void cimagf() {} ;
void cimagl() {} ;
void clog() {} ;
void clog10() {} ;
void clog10f() {} ;
void clog10l() {} ;
void clogf() {} ;
void clogl() {} ;
void conj() {} ;
void conjf() {} ;
void conjl() {} ;
void copysign() {} ;
void copysignf() {} ;
void copysignl() {} ;
void cos() {} ;
void cosf() {} ;
void cosh() {} ;
void coshf() {} ;
void coshl() {} ;
void cosl() {} ;
void cpow() {} ;
void cpowf() {} ;
void cpowl() {} ;
void cproj() {} ;
void cprojf() {} ;
void cprojl() {} ;
void creal() {} ;
void crealf() {} ;
void creall() {} ;
void csin() {} ;
void csinf() {} ;
void csinh() {} ;
void csinhf() {} ;
void csinhl() {} ;
void csinl() {} ;
void csqrt() {} ;
void csqrtf() {} ;
void csqrtl() {} ;
void ctan() {} ;
void ctanf() {} ;
void ctanh() {} ;
void ctanhf() {} ;
void ctanhl() {} ;
void ctanl() {} ;
void dremf() {} ;
void dreml() {} ;
void erf() {} ;
void erfc() {} ;
void erfcf() {} ;
void erfcl() {} ;
void erff() {} ;
void erfl() {} ;
void exp() {} ;
void exp2() {} ;
void exp2f() {} ;
void expf() {} ;
void expl() {} ;
void expm1() {} ;
void expm1f() {} ;
void expm1l() {} ;
void fabs() {} ;
void fabsf() {} ;
void fabsl() {} ;
void fdim() {} ;
void fdimf() {} ;
void fdiml() {} ;
void feclearexcept() {} ;
void fegetenv() {} ;
void fegetexceptflag() {} ;
void fegetround() {} ;
void feholdexcept() {} ;
void feraiseexcept() {} ;
void fesetenv() {} ;
void fesetexceptflag() {} ;
void fesetround() {} ;
void fetestexcept() {} ;
void feupdateenv() {} ;
void finite() {} ;
void finitef() {} ;
void finitel() {} ;
void floor() {} ;
void floorf() {} ;
void floorl() {} ;
void fma() {} ;
void fmaf() {} ;
void fmal() {} ;
void fmax() {} ;
void fmaxf() {} ;
void fmaxl() {} ;
void fmin() {} ;
void fminf() {} ;
void fminl() {} ;
void fmod() {} ;
void fmodf() {} ;
void fmodl() {} ;
void frexp() {} ;
void frexpf() {} ;
void frexpl() {} ;
void gamma() {} ;
void gammaf() {} ;
void gammal() {} ;
void hypot() {} ;
void hypotf() {} ;
void hypotl() {} ;
void ilogb() {} ;
void ilogbf() {} ;
void ilogbl() {} ;
void j0() {} ;
void j0f() {} ;
void j0l() {} ;
void j1() {} ;
void j1f() {} ;
void j1l() {} ;
void jn() {} ;
void jnf() {} ;
void jnl() {} ;
void ldexp() {} ;
void ldexpf() {} ;
void ldexpl() {} ;
void lgamma() {} ;
void lgamma_r() {} ;
void lgammaf() {} ;
void lgammaf_r() {} ;
void lgammal() {} ;
void lgammal_r() {} ;
void llrint() {} ;
void llrintf() {} ;
void llrintl() {} ;
void llround() {} ;
void llroundf() {} ;
void llroundl() {} ;
void log() {} ;
void log10() {} ;
void log10f() {} ;
void log10l() {} ;
void log1p() {} ;
void log1pf() {} ;
void log1pl() {} ;
void log2() {} ;
void log2f() {} ;
void log2l() {} ;
void logb() {} ;
void logbf() {} ;
void logbl() {} ;
void logf() {} ;
void logl() {} ;
void lrint() {} ;
void lrintf() {} ;
void lrintl() {} ;
void lround() {} ;
void lroundf() {} ;
void lroundl() {} ;
void matherr() {} ;
void modf() {} ;
void modff() {} ;
void modfl() {} ;
void nan() {} ;
void nanf() {} ;
void nanl() {} ;
void nearbyint() {} ;
void nearbyintf() {} ;
void nearbyintl() {} ;
void nextafter() {} ;
void nextafterf() {} ;
void nextafterl() {} ;
void nexttoward() {} ;
void nexttowardf() {} ;
void nexttowardl() {} ;
void pow() {} ;
void pow10() {} ;
void pow10f() {} ;
void pow10l() {} ;
void powf() {} ;
void powl() {} ;
void remainder() {} ;
void remainderf() {} ;
void remainderl() {} ;
void remquo() {} ;
void remquof() {} ;
void remquol() {} ;
void rint() {} ;
void rintf() {} ;
void rintl() {} ;
void round() {} ;
void roundf() {} ;
void roundl() {} ;
void scalb() {} ;
void scalbf() {} ;
void scalbl() {} ;
void scalbln() {} ;
void scalblnf() {} ;
void scalblnl() {} ;
void scalbn() {} ;
void scalbnf() {} ;
void scalbnl() {} ;
void significand() {} ;
void significandf() {} ;
void significandl() {} ;
void sin() {} ;
void sincos() {} ;
void sincosf() {} ;
void sincosl() {} ;
void sinf() {} ;
void sinh() {} ;
void sinhf() {} ;
void sinhl() {} ;
void sinl() {} ;
void sqrt() {} ;
void sqrtf() {} ;
void sqrtl() {} ;
void tan() {} ;
void tanf() {} ;
void tanh() {} ;
void tanhf() {} ;
void tanhl() {} ;
void tanl() {} ;
void tgamma() {} ;
void tgammaf() {} ;
void tgammal() {} ;
void trunc() {} ;
void truncf() {} ;
void truncl() {} ;
void y0() {} ;
void y0f() {} ;
void y0l() {} ;
void y1() {} ;
void y1f() {} ;
void y1l() {} ;
void yn() {} ;
void ynf() {} ;
void ynl() {} ;
__asm__(".globl signgam; .pushsection .data; .type signgam,@object; .size signgam, 4; signgam: .long 0; .popsection");

==> lsb-build-base3_3.2.2~pre1.orig.tar.gz: lsb-build-base-3.2.2/build_env/stub_libs/S390X/libm.c <==
void __finite() {} ;
void __finitef() {} ;
void __finitel() {} ;
void __fpclassify() {} ;
void __fpclassifyf() {} ;
void __signbit() {} ;
void __signbitf() {} ;
void acos() {} ;
void acosf() {} ;
void acosh() {} ;
void acoshf() {} ;
void acoshl() {} ;
void acosl() {} ;
void asin() {} ;
void asinf() {} ;
void asinh() {} ;
void asinhf() {} ;
void asinhl() {} ;
void asinl() {} ;
void atan() {} ;
void atan2() {} ;
void atan2f() {} ;
void atan2l() {} ;
void atanf() {} ;
void atanh() {} ;
void atanhf() {} ;
void atanhl() {} ;
void atanl() {} ;
void cabs() {} ;
void cabsf() {} ;
void cabsl() {} ;
void cacos() {} ;
void cacosf() {} ;
void cacosh() {} ;
void cacoshf() {} ;
void cacoshl() {} ;
void cacosl() {} ;
void carg() {} ;
void cargf() {} ;
void cargl() {} ;
void casin() {} ;
void casinf() {} ;
void casinh() {} ;
void casinhf() {} ;
void casinhl() {} ;
void casinl() {} ;
void catan() {} ;
void catanf() {} ;
void catanh() {} ;
void catanhf() {} ;
void catanhl() {} ;
void catanl() {} ;
void cbrt() {} ;
void cbrtf() {} ;
void cbrtl() {} ;
void ccos() {} ;
void ccosf() {} ;
void ccosh() {} ;
void ccoshf() {} ;
void ccoshl() {} ;
void ccosl() {} ;
void ceil() {} ;
void ceilf() {} ;
void ceill() {} ;
void cexp() {} ;
void cexpf() {} ;
void cexpl() {} ;
void cimag() {} ;
void cimagf() {} ;
void cimagl() {} ;
void clog() {} ;
void clog10() {} ;
void clog10f() {} ;
void clog10l() {} ;
void clogf() {} ;
void clogl() {} ;
void conj() {} ;
void conjf() {} ;
void conjl() {} ;
void copysign() {} ;
void copysignf() {} ;
void copysignl() {} ;
void cos() {} ;
void cosf() {} ;
void cosh() {} ;
void coshf() {} ;
void coshl() {} ;
void cosl() {} ;
void cpow() {} ;
void cpowf() {} ;
void cpowl() {} ;
void cproj() {} ;
void cprojf() {} ;
void cprojl() {} ;
void creal() {} ;
void crealf() {} ;
void creall() {} ;
void csin() {} ;
void csinf() {} ;
void csinh() {} ;
void csinhf() {} ;
void csinhl() {} ;
void csinl() {} ;
void csqrt() {} ;
void csqrtf() {} ;
void csqrtl() {} ;
void ctan() {} ;
void ctanf() {} ;
void ctanh() {} ;
void ctanhf() {} ;
void ctanhl() {} ;
void ctanl() {} ;
void drem() {} ;
void dremf() {} ;
void dreml() {} ;
void erf() {} ;
void erfc() {} ;
void erfcf() {} ;
void erfcl() {} ;
void erff() {} ;
void erfl() {} ;
void exp() {} ;
void exp10() {} ;
void exp10f() {} ;
void exp10l() {} ;
void exp2() {} ;
void exp2f() {} ;
void expf() {} ;
void expl() {} ;
void expm1() {} ;
void expm1f() {} ;
void expm1l() {} ;
void fabs() {} ;
void fabsf() {} ;
void fabsl() {} ;
void fdim() {} ;
void fdimf() {} ;
void fdiml() {} ;
void feclearexcept() {} ;
void fedisableexcept() {} ;
void feenableexcept() {} ;
void fegetenv() {} ;
void fegetexcept() {} ;
void fegetexceptflag() {} ;
void fegetround() {} ;
void feholdexcept() {} ;
void feraiseexcept() {} ;
void fesetenv() {} ;
void fesetexceptflag() {} ;
void fesetround() {} ;
void fetestexcept() {} ;
void feupdateenv() {} ;
void finite() {} ;
void finitef() {} ;
void finitel() {} ;
void floor() {} ;
void floorf() {} ;
void floorl() {} ;
void fma() {} ;
void fmaf() {} ;
void fmal() {} ;
void fmax() {} ;
void fmaxf() {} ;
void fmaxl() {} ;
void fmin() {} ;
void fminf() {} ;
void fminl() {} ;
void fmod() {} ;
void fmodf() {} ;
void fmodl() {} ;
void frexp() {} ;
void frexpf() {} ;
void frexpl() {} ;
void gamma() {} ;
void gammaf() {} ;
void gammal() {} ;
void hypot() {} ;
void hypotf() {} ;
void hypotl() {} ;
void ilogb() {} ;
void ilogbf() {} ;
void ilogbl() {} ;
void j0() {} ;
void j0f() {} ;
void j0l() {} ;
void j1() {} ;
void j1f() {} ;
void j1l() {} ;
void jn() {} ;
void jnf() {} ;
void jnl() {} ;
void ldexp() {} ;
void ldexpf() {} ;
void ldexpl() {} ;
void lgamma() {} ;
void lgamma_r() {} ;
void lgammaf() {} ;
void lgammaf_r() {} ;
void lgammal() {} ;
void lgammal_r() {} ;
void llrint() {} ;
void llrintf() {} ;
void llrintl() {} ;
void llround() {} ;
void llroundf() {} ;
void llroundl() {} ;
void log() {} ;
void log10() {} ;
void log10f() {} ;
void log10l() {} ;
void log1p() {} ;
void log1pf() {} ;
void log1pl() {} ;
void log2() {} ;
void log2f() {} ;
void log2l() {} ;
void logb() {} ;
void logbf() {} ;
void logbl() {} ;
void logf() {} ;
void logl() {} ;
void lrint() {} ;
void lrintf() {} ;
void lrintl() {} ;
void lround() {} ;
void lroundf() {} ;
void lroundl() {} ;
void matherr() {} ;
void modf() {} ;
void modff() {} ;
void modfl() {} ;
void nan() {} ;
void nanf() {} ;
void nanl() {} ;
void nearbyint() {} ;
void nearbyintf() {} ;
void nearbyintl() {} ;
void nextafter() {} ;
void nextafterf() {} ;
void nextafterl() {} ;
void nexttoward() {} ;
void nexttowardf() {} ;
void nexttowardl() {} ;
void pow() {} ;
void pow10() {} ;
void pow10f() {} ;
void pow10l() {} ;
void powf() {} ;
void powl() {} ;
void remainder() {} ;
void remainderf() {} ;
void remainderl() {} ;
void remquo() {} ;
void remquof() {} ;
void remquol() {} ;
void rint() {} ;
void rintf() {} ;
void rintl() {} ;
void round() {} ;
void roundf() {} ;
void roundl() {} ;
void scalb() {} ;
void scalbf() {} ;
void scalbl() {} ;
void scalbln() {} ;
void scalblnf() {} ;
void scalblnl() {} ;
void scalbn() {} ;
void scalbnf() {} ;
void scalbnl() {} ;
void significand() {} ;
void significandf() {} ;
void significandl() {} ;
void sin() {} ;
void sincos() {} ;
void sincosf() {} ;
void sincosl() {} ;
void sinf() {} ;
void sinh() {} ;
void sinhf() {} ;
void sinhl() {} ;
void sinl() {} ;
void sqrt() {} ;
void sqrtf() {} ;
void sqrtl() {} ;
void tan() {} ;
void tanf() {} ;
void tanh() {} ;
void tanhf() {} ;
void tanhl() {} ;
void tanl() {} ;
void tgamma() {} ;
void tgammaf() {} ;
void tgammal() {} ;
void trunc() {} ;
void truncf() {} ;
void truncl() {} ;
void y0() {} ;
void y0f() {} ;
void y0l() {} ;
void y1() {} ;
void y1f() {} ;
void y1l() {} ;
void yn() {} ;
void ynf() {} ;
void ynl() {} ;
__asm__(".globl signgam; .pushsection .data; .type signgam,@object; .size signgam, 4; signgam: .long 0; .popsection");
